@@ -9,8 +9,8 @@ from . import scripts
 
 __title__ = 'python_plus'
 __author__ = 'Antonio Maria Vigliotti'
-__copyright__ = 'Copyright 2018-2024 SHS-AV srl'
-__version__ = '2.0.15'
+__copyright__ = 'Copyright 2018-2025 SHS-AV srl'
+__version__ = '2.0.16'
 
 PYCODESET = 'utf-8'
 if PY3:
@@ -18,7 +18,7 @@ if PY3:
     bytestr_type = bytes
 elif PY2:
     # unicode exist only for python2
-    text_type = unicode
+    text_type = unicode         # noqa: F821
     bytestr_type = str
 
 
@@ -288,3 +288,4 @@ class __(object, with_metaclass(Base__, text_type)):
             enquote=enquote,
             strip=strip,
         )
+
